(TeX-add-style-hook
 "REFERENCES"
 (lambda ()
   (LaTeX-add-bibitems
    "BrockwellDavis1991"
    "FrancqZakoian2010garch"
    "Li2004diagnostic"
    "McLeodYuKrougly2007"
    "kokoszka2011nonlinearity"
    "gardner+harvey+phillips:1980"))
 :bibtex)

